@@ -34,10 +34,16 @@ import (
 	"github.com/swaggo/gin-swagger/swaggerFiles"
 )
 
+const DB_MIGRATION_REQUIRED = `
+New migration scripts detected. Database migration is required to launch DevLake.
+WARNING: Performing migration may wipe collected data for consistency and re-collecting data may be required.
+To proceed, please send a request to <config-ui-endpoint>/api/proceed-db-migration (or <devlake-endpoint>/proceed-db-migration).
+Alternatively, you may downgrade back to the previous DevLake version.
+`
+
 // @title  DevLake Swagger API
 // @version 0.1
 // @description  <h2>This is the main page of devlake api</h2>
-// sdfasdfasd
 // @license.name Apache-2.0
 // @host localhost:8080
 // @BasePath /
@@ -66,10 +72,7 @@ func CreateApiService() {
 		}
 		shared.ApiOutputError(
 			ctx,
-			fmt.Errorf("Database migration is required for Apache DevLake to function properly, it might cause the "+
-				"collected data gets wiped out for consistency. \nPlease send a request to `/proceed-db-migration` "+
-				"(or `/api/proceed-db-migration` from config-ui)if it is ok, or you may downgrade back to the older "+
-				"version you previous used."),
+			fmt.Errorf(DB_MIGRATION_REQUIRED),
 			http.StatusPreconditionRequired,
 		)
 		ctx.Abort()
