@@ -18,7 +18,11 @@ limitations under the License.
 package pipelines
 
 import (
+	goerror "errors"
+	"github.com/apache/incubator-devlake/errors"
 	"net/http"
+	"os"
+	"path/filepath"
 	"strconv"
 
 	"github.com/apache/incubator-devlake/api/shared"
@@ -41,20 +45,12 @@ POST /pipelines
 */
 // @Summary Create and run a new pipeline
 // @Description Create and run a new pipeline
-// @Description RETURN SAMPLE
-// @Description {
-// @Description 	"name": "name-of-pipeline",
-// @Description 	"tasks": [
-// @Description 		[ {"plugin": "gitlab", ...}, {"plugin": "jira"} ],
-// @Description 		[ {"plugin": "github", ...}],
-// @Description 	]
-// @Description }
-// @Tags pipelines
+// @Tags framework/pipelines
 // @Accept application/json
-// @Param pipeline body string true "json"
+// @Param pipeline body models.NewPipeline true "json"
 // @Success 200  {object} models.Pipeline
 // @Failure 400  {string} errcode.Error "Bad Request"
-// @Failure 500  {string} errcode.Error "Internel Error"
+// @Failure 500  {string} errcode.Error "Internal Error"
 // @Router /pipelines [post]
 func Post(c *gin.Context) {
 	newPipeline := &models.NewPipeline{}
@@ -87,19 +83,12 @@ GET /pipelines?status=TASK_RUNNING&pending=1&page=1&pagesize=10
 
 // @Summary Get list of pipelines
 // @Description GET /pipelines?status=TASK_RUNNING&pending=1&page=1&pagesize=10
-// @Description RETURN SAMPLE
-// @Description {
-// @Description 	"pipelines": [
-// @Description 		{"id": 1, "name": "test-pipeline", ...}
-// @Description 	],
-// @Description 	"count": 5
-// @Description }
-// @Tags pipelines
+// @Tags framework/pipelines
 // @Param status query string true "query"
 // @Param pending query int true "query"
 // @Param page query int true "query"
 // @Param pagesize query int true "query"
-// @Success 200  {object} models.Pipeline
+// @Success 200  {object} shared.ResponsePipelines
 // @Failure 400  {string} errcode.Error "Bad Request"
 // @Failure 500  {string} errcode.Error "Internel Error"
 // @Router /pipelines [get]
@@ -115,7 +104,7 @@ func Index(c *gin.Context) {
 		shared.ApiOutputError(c, err, http.StatusBadRequest)
 		return
 	}
-	shared.ApiOutputSuccess(c, gin.H{"pipelines": pipelines, "count": count}, http.StatusOK)
+	shared.ApiOutputSuccess(c, shared.ResponsePipelines{Pipelines: pipelines, Count: count}, http.StatusOK)
 }
 
 /*
@@ -135,7 +124,7 @@ GET /pipelines/:pipelineId
 // @Description 	"name": "test-pipeline",
 // @Description 	...
 // @Description }
-// @Tags pipelines
+// @Tags framework/pipelines
 // @Param pipelineId path int true "query"
 // @Success 200  {object} models.Pipeline
 // @Failure 400  {string} errcode.Error "Bad Request"
@@ -162,7 +151,7 @@ DELETE /pipelines/:pipelineId
 */
 // @Cancel a pending pipeline
 // @Description Cancel a pending pipeline
-// @Tags pipelines
+// @Tags framework/pipelines
 // @Param pipelineId path int true "pipeline ID"
 // @Success 200
 // @Failure 400  {string} errcode.Error "Bad Request"
@@ -182,3 +171,45 @@ func Delete(c *gin.Context) {
 	}
 	shared.ApiOutputSuccess(c, nil, http.StatusOK)
 }
+
+/*
+Get download logs of a pipeline
+GET /pipelines/:pipelineId/logging.tar.gz
+*/
+// download logs of a pipeline
+// @Description GET /pipelines/:pipelineId/logging.tar.gz
+// @Tags framework/pipelines
+// @Param pipelineId path int true "query"
+// @Success 200  "The archive file"
+// @Failure 400  {string} errcode.Error "Bad Request"
+// @Failure 404  {string} errcode.Error "Pipeline or Log files not found"
+// @Failure 500  {string} errcode.Error "Internel Error"
+// @Router /pipelines/{pipelineId}/logging.tar.gz [get]
+func DownloadLogs(c *gin.Context) {
+	pipelineId := c.Param("pipelineId")
+	id, err := strconv.ParseUint(pipelineId, 10, 64)
+	if err != nil {
+		shared.ApiOutputError(c, err, http.StatusBadRequest)
+		return
+	}
+	pipeline, err := services.GetPipeline(id)
+	if err != nil {
+		if errors.IsNotFound(err) {
+			shared.ApiOutputError(c, err, http.StatusNotFound)
+		} else {
+			shared.ApiOutputError(c, err, http.StatusInternalServerError)
+		}
+		return
+	}
+	archive, err := services.GetPipelineLogsArchivePath(pipeline)
+	if err != nil {
+		if goerror.Is(err, os.ErrNotExist) {
+			shared.ApiOutputError(c, err, http.StatusNotFound)
+		} else {
+			shared.ApiOutputError(c, err, http.StatusInternalServerError)
+		}
+		return
+	}
+	defer os.Remove(archive)
+	c.FileAttachment(archive, filepath.Base(archive))
+}
