@@ -26,6 +26,7 @@ import (
 	"github.com/apache/incubator-devlake/api/domainlayer"
 	"github.com/apache/incubator-devlake/api/ping"
 	"github.com/apache/incubator-devlake/api/pipelines"
+	"github.com/apache/incubator-devlake/api/plugininfo"
 	"github.com/apache/incubator-devlake/api/push"
 	"github.com/apache/incubator-devlake/api/shared"
 	"github.com/apache/incubator-devlake/api/task"
@@ -46,14 +47,19 @@ func RegisterRouter(r *gin.Engine) {
 	r.GET("/blueprints", blueprints.Index)
 	r.POST("/blueprints", blueprints.Post)
 	r.GET("/blueprints/:blueprintId", blueprints.Get)
+	r.GET("/blueprints/:blueprintId/pipelines", blueprints.GetBlueprintPipelines)
 	r.DELETE("/pipelines/:pipelineId", pipelines.Delete)
 	r.GET("/pipelines/:pipelineId/tasks", task.Index)
 
+	r.GET("/pipelines/:pipelineId/logging.tar.gz", pipelines.DownloadLogs)
+
 	r.GET("/ping", ping.Get)
 	r.GET("/version", version.Get)
 	r.POST("/push/:tableName", push.Post)
 	r.GET("/domainlayer/repos", domainlayer.ReposIndex)
 
+	r.GET("/plugininfo", plugininfo.Get)
+
 	// mount all api resources for all plugins
 	pluginsApiResources, err := services.GetPluginsApiResources()
 	if err != nil {
