@@ -20,6 +20,7 @@ package shared
 import (
 	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/logger"
+	"github.com/apache/incubator-devlake/models"
 	"github.com/gin-gonic/gin"
 )
 
@@ -28,6 +29,11 @@ type ApiBody struct {
 	Message string `json:"message"`
 }
 
+type ResponsePipelines struct {
+	Count     int64              `json:"count"`
+	Pipelines []*models.Pipeline `json:"pipelines"`
+}
+
 func ApiOutputError(c *gin.Context, err error, status int) {
 	if e, ok := err.(*errors.Error); ok {
 		c.JSON(e.Status, &ApiBody{
