@@ -15,6 +15,7 @@
  * limitations under the License.
  *
  */
+import React from 'react'
 import { ProviderLabels } from '@/data/Providers'
 import { GRAFANA_URL } from '@/utils/config'
 
@@ -59,6 +60,14 @@ const MenuConfiguration = (activeRoute) => {
           active: activeRoute.url.endsWith('/integrations/jenkins') || activeRoute.url.endsWith('/jenkins'),
           icon: 'layers',
           classNames: [],
+        },
+        {
+          id: 4,
+          label: `${ProviderLabels.TAPD} (beta)`,
+          route: '/integrations/tapd',
+          active: activeRoute.url.endsWith('/integrations/tapd') || activeRoute.url.endsWith('/tapd'),
+          icon: 'layers',
+          classNames: [],
         }
       ]
     },
