@@ -19,5 +19,5 @@ import { Position, Toaster } from '@blueprintjs/core'
 
 export const ToastNotification = Toaster.create({
   className: 'recipe-toaster',
-  position: Position.BOTTOM_RIGHT,
+  position: Position.BOTTOM,
 })
