@@ -21,6 +21,7 @@ import { ReactComponent as GitlabProviderIcon } from '@/images/integrations/gitl
 import { ReactComponent as JenkinsProviderIcon } from '@/images/integrations/jenkins.svg'
 import { ReactComponent as JiraProviderIcon } from '@/images/integrations/jira.svg'
 import { ReactComponent as GitHubProviderIcon } from '@/images/integrations/github.svg'
+import { ReactComponent as TapdProviderIcon } from '@/images/integrations/tapd.svg'
 // import GitExtractorIcon from '@/images/git.png'
 // import RefDiffIcon from '@/images/git-diff.png'
 import FeishuIcon from '@/images/feishu.png'
@@ -39,6 +40,7 @@ const Providers = {
   AE: 'ae',
   DBT: 'dbt',
   STARROCKS: 'starrocks',
+  TAPD: 'tapd',
 }
 
 const ProviderTypes = {
@@ -59,6 +61,7 @@ const ProviderLabels = {
   AE: 'Analysis Engine (AE)',
   DBT: 'Data Build Tool (DBT)',
   STARROCKS: 'StarRocks',
+  TAPD: 'TAPD',
 }
 
 const ProviderConnectionLimits = {
@@ -78,7 +81,8 @@ const ProviderFormLabels = {
     proxy: 'Proxy URL',
     token: 'Basic Auth Token',
     username: 'Username',
-    password: 'Password'
+    password: 'Password',
+    rateLimit: 'Rate Limit'
   },
   gitlab: {
     name: 'Connection Name',
@@ -86,7 +90,8 @@ const ProviderFormLabels = {
     proxy: 'Proxy URL',
     token: 'Access Token',
     username: 'Username',
-    password: 'Password'
+    password: 'Password',
+    rateLimit: <>Rate Limit <sup>(per hour)</sup></>
   },
   jenkins: {
     name: 'Connection Name',
@@ -94,15 +99,24 @@ const ProviderFormLabels = {
     proxy: 'Proxy URL',
     token: 'Basic Auth Token',
     username: 'Username',
-    password: 'Password'
+    password: 'Password',
+    rateLimit: <>Rate Limit <sup>(per hour)</sup></>
   },
-  jira: {
+  tapd: {
     name: 'Connection Name',
     endpoint: 'Endpoint URL',
     proxy: 'Proxy URL',
     token: 'Basic Auth Token',
+    username: 'Username',
+    password: 'Password',
+    rateLimit: <>Rate Limit <sup>(per hour)</sup></>
+  },
+  jira: {
+    name: 'Connection Name',
+    endpoint: 'Endpoint URL',
+    token: 'Basic Auth Token',
     username: 'Username / E-mail',
-    // password; 'Password',
+    proxy: 'Proxy URL',
     password: (
       <>
         Password
@@ -124,17 +138,17 @@ const ProviderFormLabels = {
           />
         </Tooltip>
       </>),
+    rateLimit: <>Rate Limit <sup>(per hour)</sup></>
   },
   github: {
     name: 'Connection Name',
     endpoint: 'Endpoint URL',
     proxy: 'Proxy URL',
-    // token: 'Auth Token(s)',
     token: (
       <>
         Auth Token(s)
         <Tooltip
-          content={(<span>Due to Github’s rate limit, input more tokens, <br />comma separated, to accelerate data collection.</span>)}
+          content={(<span>Due to Github's rate limit, input more tokens, <br />comma separated, to accelerate data collection.</span>)}
           intent='primary'
         >
           <Icon
@@ -152,8 +166,9 @@ const ProviderFormLabels = {
         </Tooltip>
       </>),
     username: 'Username',
-    password: 'Password'
-  },
+    password: 'Password',
+    rateLimit: <>Rate Limit <sup>(per hour)</sup></>
+  }
 }
 
 const ProviderFormPlaceholders = {
@@ -163,7 +178,8 @@ const ProviderFormPlaceholders = {
     proxy: 'eg. http://proxy.localhost:8080',
     token: 'eg. 3f5cda2a23ff410792e0',
     username: 'Enter Username / E-mail',
-    password: 'Enter Password'
+    password: 'Enter Password',
+    rateLimit: '1000'
   },
   gitlab: {
     name: 'eg. GitLab',
@@ -171,7 +187,8 @@ const ProviderFormPlaceholders = {
     proxy: 'eg. http://proxy.localhost:8080',
     token: 'eg. ff9d1ad0e5c04f1f98fa',
     username: 'Enter Username / E-mail',
-    password: 'Enter Password'
+    password: 'Enter Password',
+    rateLimit: '1000'
   },
   jenkins: {
     name: 'eg. Jenkins',
@@ -179,7 +196,17 @@ const ProviderFormPlaceholders = {
     proxy: 'eg. http://proxy.localhost:8080',
     token: 'eg. 6b057ffe68464c93a057',
     username: 'eg. admin',
-    password: 'eg. ************'
+    password: 'eg. ************',
+    rateLimit: '1000'
+  },
+  tapd: {
+    name: 'eg. Tapd',
+    endpoint: 'URL eg. https://api.tapd.cn/',
+    proxy: 'eg. http://proxy.localhost:8080',
+    token: 'eg. 6b057ffe68464c93a057',
+    username: 'eg. admin',
+    password: 'eg. ************',
+    rateLimit: '1000'
   },
   jira: {
     name: 'eg. JIRA',
@@ -187,7 +214,8 @@ const ProviderFormPlaceholders = {
     proxy: 'eg. http://proxy.localhost:8080',
     token: 'eg. 8c06a7cc50b746bfab30',
     username: 'eg. admin',
-    password: 'eg. ************'
+    password: 'eg. ************',
+    rateLimit: '1000'
   },
   github: {
     name: 'eg. GitHub',
@@ -195,13 +223,15 @@ const ProviderFormPlaceholders = {
     proxy: 'eg. http://proxy.localhost:8080',
     token: 'eg. 4c5cbdb62c165e2b3d18, 40008ebccff9837bb8d2',
     username: 'eg. admin',
-    password: 'eg. ************'
+    password: 'eg. ************',
+    rateLimit: '1000'
   }
 }
 
 const ProviderIcons = {
   [Providers.GITLAB]: (w, h) => <GitlabProviderIcon width={w || 24} height={h || 24} />,
   [Providers.JENKINS]: (w, h) => <JenkinsProviderIcon width={w || 24} height={h || 24} />,
+  [Providers.TAPD]: (w, h) => <TapdProviderIcon width={w || 24} height={h || 24} />,
   [Providers.JIRA]: (w, h) => <JiraProviderIcon width={w || 24} height={h || 24} />,
   [Providers.GITHUB]: (w, h) => <GitHubProviderIcon width={w || 24} height={h || 24} />,
   [Providers.REFDIFF]: (w, h) => <Icon icon='box' size={w || 24} />,
