@@ -18,27 +18,31 @@
 const defaultConfig = [
   [
     {
-      Plugin: 'gitlab',
-      Options: {
-        projectId: 8967944
+      plugin: 'gitlab',
+      options: {
+        projectId: 8967944,
+        connectionId: 1
       }
     },
     {
-      Plugin: 'jira',
-      Options: {
+      plugin: 'jira',
+      options: {
         boardId: 8,
         connectionId: 1
       }
     },
     {
-      Plugin: 'jenkins',
-      Options: {}
+      plugin: 'jenkins',
+      options: {
+        connectionId: 1
+      }
     },
     {
-      Plugin: 'github',
-      Options: {
+      plugin: 'github',
+      options: {
         repo: 'lake',
-        owner: 'merico-dev'
+        owner: 'merico-dev',
+        connectionId: 1
       }
     }
   ]
