@@ -16,10 +16,11 @@
  *
  */
 const githubConfig = [[{
-  Plugin: 'github',
-  Options: {
+  plugin: 'github',
+  options: {
     repo: 'lake',
-    owner: 'merico-dev'
+    owner: 'merico-dev',
+    connectionId: 1
   }
 }]]
 
