@@ -16,9 +16,10 @@
  *
  */
 const gitlabConfig = [[{
-  Plugin: 'gitlab',
-  Options: {
-    projectId: 278964
+  plugin: 'gitlab',
+  options: {
+    projectId: 278964,
+    connectionId: 1
   }
 }]]
 
