@@ -18,8 +18,10 @@
 const jenkinsConfig = [
   [
     {
-      Plugin: 'jenkins',
-      Options: {}
+      plugin: 'jenkins',
+      options: {
+        connectionId: 1
+      }
     }
   ]
 ]
