@@ -18,8 +18,8 @@
 const jiraConfig = [
   [
     {
-      Plugin: 'jira',
-      Options: {
+      plugin: 'jira',
+      options: {
         connectionId: 1,
         boardId: 8,
         since: '2006-01-02T15:04:05Z'
