@@ -18,8 +18,8 @@
 const refdiffConfig = [
   [
     {
-      Plugin: 'refdiff',
-      Options: {
+      plugin: 'refdiff',
+      options: {
         repoId: 'github:GithubRepo:384111310',
         pairs: [
           { newRef: 'refs/tags/v0.6.0', oldRef: 'refs/tags/0.5.0' },
