@@ -18,13 +18,14 @@
 const starRocksConfig = [
   [
     {
-      Plugin: 'starrocks',
-      Options: {
+      plugin: 'starrocks',
+      options: {
         host: '127.0.0.1',
         port: 9030,
         user: 'root',
         password: '',
         database: 'lake',
+        be_host: '',
         be_port: 8040,
         tables: ['_tool_.*'], // support regexp
         batch_size: 10000,
