@@ -44,6 +44,7 @@ function useConnectionManager (
   const [name, setName] = useState()
   const [endpointUrl, setEndpointUrl] = useState()
   const [proxy, setProxy] = useState()
+  const [rateLimit, setRateLimit] = useState(0)
   const [token, setToken] = useState()
   const [initialTokenStore, setInitialTokenStore] = useState({
     0: '',
@@ -74,6 +75,8 @@ function useConnectionManager (
   const [connectionCount, setConnectionCount] = useState(0)
   const [connectionLimitReached, setConnectionLimitReached] = useState(false)
 
+  const [connectionsList, setConnectionsList] = useState([])
+
   const [saveComplete, setSaveComplete] = useState(false)
   const [deleteComplete, setDeleteComplete] = useState(false)
   const connectionTestPayload = useMemo(() => ({ endpoint: endpointUrl, username, password, token, proxy }), [endpointUrl, password, proxy, token, username])
@@ -146,6 +149,18 @@ function useConnectionManager (
           username: username,
           password: password,
           proxy: proxy,
+          rateLimitPerHour: rateLimit,
+          ...connectionPayload,
+        }
+        break
+      case Providers.TAPD:
+        connectionPayload = {
+          name: name,
+          endpoint: endpointUrl,
+          username: username,
+          password: password,
+          proxy: proxy,
+          rateLimitPerHour: rateLimit,
           ...connectionPayload,
         }
         break
@@ -155,6 +170,7 @@ function useConnectionManager (
           endpoint: endpointUrl,
           token: token,
           proxy: proxy,
+          rateLimitPerHour: rateLimit,
           ...connectionPayload,
         }
         break
@@ -165,6 +181,7 @@ function useConnectionManager (
           endpoint: endpointUrl,
           username: username,
           password: password,
+          rateLimitPerHour: rateLimit,
           ...connectionPayload,
         }
         break
@@ -174,6 +191,7 @@ function useConnectionManager (
           endpoint: endpointUrl,
           token: token,
           proxy: proxy,
+          rateLimitPerHour: rateLimit,
           ...connectionPayload,
         }
         break
@@ -302,12 +320,14 @@ function useConnectionManager (
           )
           const connectionData = f.data
           console.log('>> RAW CONNECTION DATA FROM API...', connectionData)
+          // @todo: cleanup legacy api pascal-case parameters
           setActiveConnection({
             ...connectionData,
             ID: connectionData.ID || connectionData.id,
             name: connectionData.name || connectionData.Name,
             endpoint: connectionData.endpoint || connectionData.Endpoint,
             proxy: connectionData.proxy || connectionData.Proxy,
+            rateLimit: connectionData.rateLimitPerHour,
             username: connectionData.username || connectionData.Username,
             password: connectionData.password || connectionData.Password,
             token: connectionData.token || connectionData.auth
@@ -341,6 +361,7 @@ function useConnectionManager (
         console.log('>> FETCHING ALL CONNECTION SOURCES')
         let c = null
         if (allSources) {
+          // @todo: build promises dynamically from $integrationsData
           const aC = await Promise.all([
             request.get(
               `${DEVLAKE_ENDPOINT}/plugins/${Providers.JIRA}/connections`
@@ -354,6 +375,9 @@ function useConnectionManager (
             request.get(
               `${DEVLAKE_ENDPOINT}/plugins/${Providers.GITHUB}/connections`
             ),
+            request.get(
+              `${DEVLAKE_ENDPOINT}/plugins/${Providers.TAPD}/connections`
+            ),
           ])
           const builtConnections = aC
             .map((providerResponse) => [].concat(providerResponse.data || []).map(c => ({
@@ -382,6 +406,7 @@ function useConnectionManager (
               ...conn,
               status: ConnectionStatus.OFFLINE,
               ID: conn.ID || conn.id,
+              id: conn.id,
               name: conn.name,
               endpoint: conn.endpoint,
               errors: [],
@@ -526,6 +551,7 @@ function useConnectionManager (
       2: ''
     })
     setProxy('')
+    setRateLimit(0)
   }, [])
 
   useEffect(() => {
@@ -537,22 +563,32 @@ function useConnectionManager (
         case Providers.JENKINS:
           setUsername(activeConnection.username)
           setPassword(activeConnection.password)
+          setRateLimit(activeConnection.rateLimitPerHour)
           break
         case Providers.GITLAB:
           setToken(activeConnection.basicAuthEncoded || activeConnection.token || activeConnection.auth)
           setProxy(activeConnection.Proxy || activeConnection.proxy)
+          setRateLimit(activeConnection.rateLimitPerHour)
           break
         case Providers.GITHUB:
           setToken(connectionToken)
           setInitialTokenStore(connectionToken?.split(',')?.reduce((tS, cT, id) => ({ ...tS, [id]: cT }), {}))
           setProxy(activeConnection.Proxy || activeConnection.proxy)
+          setRateLimit(activeConnection.rateLimitPerHour)
           break
         case Providers.JIRA:
         // setToken(activeConnection.basicAuthEncoded || activeConnection.token)
           setUsername(activeConnection.username)
           setPassword(activeConnection.password)
           setProxy(activeConnection.Proxy || activeConnection.proxy)
+          setRateLimit(activeConnection.rateLimitPerHour)
           break
+        case Providers.TAPD:
+          setUsername(activeConnection.username)
+          setPassword(activeConnection.password)
+          setProxy(activeConnection.Proxy || activeConnection.proxy)
+          setRateLimit(activeConnection.rateLimitPerHour)
+        break
       }
       ToastNotification.clear()
       // ToastNotification.show({ message: `Fetched settings for ${activeConnection.name}.`, intent: 'success', icon: 'small-tick' })
@@ -598,6 +634,28 @@ function useConnectionManager (
     setProvider(activeProvider)
   }, [activeProvider])
 
+  useEffect(() => {
+    console.log('>>> ALL DATA PROVIDER CONNECTIONS...', allProviderConnections)
+    setConnectionsList(
+      allProviderConnections?.map((c, cIdx) => ({
+        ...c,
+        id: cIdx,
+        key: cIdx,
+        connectionId: c.id,
+        name: c.name,
+        title: c.name,
+        value: c.id,
+        status:
+          ConnectionStatusLabels[c.status] ||
+          ConnectionStatusLabels[ConnectionStatus.OFFLINE],
+        statusResponse: null,
+        provider: c.provider,
+        providerId: c.provider,
+        plugin: c.provider,
+      }))
+    )
+  }, [allProviderConnections])
+
   return {
     activeConnection,
     fetchConnection,
@@ -617,6 +675,7 @@ function useConnectionManager (
     name,
     endpointUrl,
     proxy,
+    rateLimit,
     username,
     password,
     token,
@@ -627,6 +686,7 @@ function useConnectionManager (
     setName,
     setEndpointUrl,
     setProxy,
+    setRateLimit,
     setToken,
     setInitialTokenStore,
     setUsername,
@@ -640,9 +700,11 @@ function useConnectionManager (
     setTestResponse,
     setAllTestResponses,
     setConnectionLimits,
+    setConnectionsList,
     setSaveComplete,
     allConnections,
     allProviderConnections,
+    connectionsList,
     domainRepositories,
     testedConnections,
     sourceLimits,
