@@ -25,20 +25,22 @@ const useJIRA = ({ apiProxyPath, issuesEndpoint, fieldsEndpoint, boardsEndpoint
   const [issueTypes, setIssueTypes] = useState([])
   const [fields, setFields] = useState([])
   const [boards, setBoards] = useState([])
+  const [allResources, setAllResources] = useState({ boards, fields, issueTypes })
   const [issueTypesResponse, setIssueTypesResponse] = useState([])
   const [fieldsResponse, setFieldsResponse] = useState([])
   const [boardsResponse, setBoardsResponse] = useState([])
   const [error, setError] = useState()
 
   const fetchIssueTypes = useCallback(() => {
-    if (activeConnection?.plugin !== Providers.JIRA) {
-      return
-    }
+    // if (activeConnection?.plugin !== Providers.JIRA) {
+    //   return
+    // }
     try {
       if (apiProxyPath.includes('null')) {
         throw new Error('Connection ID is Null')
       }
       setError(null)
+      setIsFetching(true)
       const fetchIssueTypes = async () => {
         const issues = await
         request
@@ -46,9 +48,9 @@ const useJIRA = ({ apiProxyPath, issuesEndpoint, fieldsEndpoint, boardsEndpoint
           .catch(e => setError(e))
         console.log('>>> JIRA API PROXY: Issues Response...', issues)
         setIssueTypesResponse(issues && Array.isArray(issues.data) ? issues.data : [])
-        setTimeout(() => {
-          setIsFetching(false)
-        }, 1000)
+        // setTimeout(() => {
+        setIsFetching(false)
+        // }, 1000)
       }
       fetchIssueTypes()
     } catch (e) {
@@ -59,14 +61,15 @@ const useJIRA = ({ apiProxyPath, issuesEndpoint, fieldsEndpoint, boardsEndpoint
   }, [issuesEndpoint, activeConnection, apiProxyPath])
 
   const fetchFields = useCallback(() => {
-    if (activeConnection?.plugin !== Providers.JIRA) {
-      return
-    }
+    // if (activeConnection?.plugin !== Providers.JIRA) {
+    //   return
+    // }
     try {
       if (apiProxyPath.includes('null')) {
         throw new Error('Connection ID is Null')
       }
       setError(null)
+      setIsFetching(true)
       const fetchIssueFields = async () => {
         const fields = await
         request
@@ -74,9 +77,9 @@ const useJIRA = ({ apiProxyPath, issuesEndpoint, fieldsEndpoint, boardsEndpoint
           .catch(e => setError(e))
         console.log('>>> JIRA API PROXY: Fields Response...', fields)
         setFieldsResponse(fields && Array.isArray(fields.data) ? fields.data : [])
-        setTimeout(() => {
-          setIsFetching(false)
-        }, 1000)
+        // setTimeout(() => {
+        setIsFetching(false)
+        // }, 1000)
       }
       fetchIssueFields()
     } catch (e) {
@@ -87,14 +90,15 @@ const useJIRA = ({ apiProxyPath, issuesEndpoint, fieldsEndpoint, boardsEndpoint
   }, [fieldsEndpoint, activeConnection, apiProxyPath])
 
   const fetchBoards = useCallback(() => {
-    if (activeConnection?.plugin !== Providers.JIRA) {
-      return
-    }
+    // if (activeConnection?.plugin !== Providers.JIRA) {
+    //   return
+    // }
     try {
       if (apiProxyPath.includes('null')) {
         throw new Error('Connection ID is Null')
       }
       setError(null)
+      setIsFetching(true)
       const fetchApiBoards = async () => {
         const boards = await
         request
@@ -102,9 +106,9 @@ const useJIRA = ({ apiProxyPath, issuesEndpoint, fieldsEndpoint, boardsEndpoint
           .catch(e => setError(e))
         console.log('>>> JIRA API PROXY: Boards Response...', boards)
         setBoardsResponse(boards && Array.isArray(boards.data?.values) ? boards.data?.values : [])
-        setTimeout(() => {
-          setIsFetching(false)
-        }, 1000)
+        // setTimeout(() => {
+        setIsFetching(false)
+        // }, 1000)
       }
       fetchApiBoards()
     } catch (e) {
@@ -114,6 +118,41 @@ const useJIRA = ({ apiProxyPath, issuesEndpoint, fieldsEndpoint, boardsEndpoint
     }
   }, [boardsEndpoint, activeConnection, apiProxyPath])
 
+  const fetchAllResources = useCallback(async (connectionId, callback = () => {}) => {
+    try {
+      if (apiProxyPath.includes('null')) {
+        throw new Error('Connection ID is Null')
+      }
+      setError(null)
+      setIsFetching(true)
+      const aR = await Promise.all([
+        request
+          .get(activeConnection?.connectionId ? boardsEndpoint.replace('[:connectionId:]', connectionId || activeConnection?.connectionId) : boardsEndpoint),
+        request
+          .get(activeConnection?.connectionId ? fieldsEndpoint.replace('[:connectionId:]', connectionId || activeConnection?.connectionId) : fieldsEndpoint),
+        request
+          .get(activeConnection?.connectionId ? issuesEndpoint.replace('[:connectionId:]', connectionId || activeConnection?.connectionId) : issuesEndpoint),
+      ])
+      console.log('>>> JIRA API PROXY: ALL API RESOURCES...', aR)
+      const apiResources = { boards: aR[0]?.data?.values || [], fields: aR[1]?.data || [], issues: aR[2].data || [] }
+      setAllResources(apiResources)
+      setBoardsResponse(Array.isArray(aR[0]?.data.values) ? aR[0]?.data.values : [])
+      setFieldsResponse(Array.isArray(aR[1]?.data) ? aR[1]?.data : [])
+      setIssueTypesResponse(Array.isArray(aR[2]?.data) ? aR[2]?.data : [])
+      setIsFetching(false)
+      callback(apiResources)
+    } catch (e) {
+      setIsFetching(false)
+      setError(e)
+      callback(e)
+    }
+  }, [
+    boardsEndpoint,
+    fieldsEndpoint,
+    issuesEndpoint,
+    activeConnection,
+    apiProxyPath])
+
   const createListData = (data = [], titleProperty = 'name', valueProperty = 'name') => {
     return data.map((d, dIdx) => ({
       ...d,
@@ -162,10 +201,12 @@ const useJIRA = ({ apiProxyPath, issuesEndpoint, fieldsEndpoint, boardsEndpoint
     fetchFields,
     fetchIssueTypes,
     fetchBoards,
+    fetchAllResources,
     createListData,
     issueTypesResponse,
     fieldsResponse,
     boardsResponse,
+    allResources,
     issueTypes,
     fields,
     boards,
