@@ -57,6 +57,7 @@ export default function AddConnection () {
     name,
     endpointUrl,
     proxy,
+    rateLimit,
     token,
     initialTokenStore,
     username,
@@ -64,6 +65,7 @@ export default function AddConnection () {
     setName,
     setEndpointUrl,
     setProxy,
+    setRateLimit,
     setUsername,
     setPassword,
     setToken,
@@ -84,6 +86,7 @@ export default function AddConnection () {
     name,
     endpointUrl,
     proxy,
+    rateLimit,
     token,
     username,
     password
@@ -112,6 +115,7 @@ export default function AddConnection () {
         case Providers.GITHUB:
         case Providers.GITLAB:
         case Providers.JIRA:
+        case Providers.TAPD:
         default:
           setName('')
           break
@@ -163,6 +167,7 @@ export default function AddConnection () {
                   name={name}
                   endpointUrl={endpointUrl}
                   proxy={proxy}
+                  rateLimit={rateLimit}
                   token={token}
                   initialTokenStore={initialTokenStore}
                   username={username}
@@ -174,6 +179,7 @@ export default function AddConnection () {
                   onNameChange={setName}
                   onEndpointChange={setEndpointUrl}
                   onProxyChange={setProxy}
+                  onRateLimitChange={setRateLimit}
                   onTokenChange={setToken}
                   onUsernameChange={setUsername}
                   onPasswordChange={setPassword}
@@ -184,7 +190,7 @@ export default function AddConnection () {
                   allTestResponses={allTestResponses}
                   errors={errors}
                   showError={showError}
-                  authType={[Providers.JENKINS, Providers.JIRA].includes(activeProvider.id) ? 'plain' : 'token'}
+                  authType={[Providers.JENKINS, Providers.JIRA, Providers.TAPD].includes(activeProvider.id) ? 'plain' : 'token'}
                   sourceLimits={ProviderConnectionLimits}
                   labels={ProviderFormLabels[activeProvider.id]}
                   placeholders={ProviderFormPlaceholders[activeProvider.id]}
