@@ -57,6 +57,7 @@ export default function ConfigureConnection () {
     name,
     endpointUrl,
     proxy,
+    rateLimit = 0,
     username,
     password,
     token,
@@ -71,6 +72,7 @@ export default function ConfigureConnection () {
     setName,
     setEndpointUrl,
     setProxy,
+    setRateLimit,
     setUsername,
     setPassword,
     setToken,
@@ -106,6 +108,7 @@ export default function ConfigureConnection () {
     name,
     endpointUrl,
     proxy,
+    rateLimit,
     token,
     username,
     password
@@ -216,7 +219,7 @@ export default function ConfigureConnection () {
                     </div>
                     {activeConnection && (
                       <>
-                        {[Providers.GITLAB, Providers.JIRA].includes(activeProvider.id) &&
+                        {[Providers.GITLAB, Providers.JIRA, Providers.TAPD].includes(activeProvider.id) &&
                         (<h2 style={{ margin: 0 }}>#{activeConnection.ID} {activeConnection.name}</h2>)}
                         <p className='page-description'>Manage settings and options for this connection.</p>
                       </>
@@ -250,18 +253,20 @@ export default function ConfigureConnection () {
                             name={name}
                             endpointUrl={endpointUrl}
                             proxy={proxy}
+                            rateLimit={rateLimit}
                             token={token}
                             initialTokenStore={initialTokenStore}
                             username={username}
                             password={password}
                             // JIRA and GITLAB are multi-connection plugins, for now we intentially won't include additional settings during save...
-                            onSave={() => saveConnection(![Providers.GITLAB, Providers.JIRA].includes(activeProvider.id) ? settings : {})}
+                            onSave={() => saveConnection(![Providers.GITLAB, Providers.JIRA, Providers.TAPD].includes(activeProvider.id) ? settings : {})}
                             onTest={testConnection}
                             onCancel={cancel}
                             onValidate={validate}
                             onNameChange={setName}
                             onEndpointChange={setEndpointUrl}
                             onProxyChange={setProxy}
+                            onRateLimitChange={setRateLimit}
                             onTokenChange={setToken}
                             onUsernameChange={setUsername}
                             onPasswordChange={setPassword}
@@ -272,7 +277,7 @@ export default function ConfigureConnection () {
                             allTestResponses={allTestResponses}
                             errors={errors}
                             showError={showConnectionError}
-                            authType={[Providers.JENKINS, Providers.JIRA].includes(activeProvider.id) ? 'plain' : 'token'}
+                            authType={[Providers.JENKINS, Providers.JIRA, Providers.TAPD].includes(activeProvider.id) ? 'plain' : 'token'}
                             showLimitWarning={false}
                             sourceLimits={ProviderConnectionLimits}
                             labels={ProviderFormLabels[activeProvider.id]}
