@@ -55,9 +55,6 @@ export default function JenkinsSettings (props) {
         <h3 className='headline'>No Additional Settings</h3>
         <p className='description'>
           This integration doesn’t require any configuration.
-          You can continue to&nbsp;
-          <a href='#' style={{ textDecoration: 'underline' }} onClick={cancel}>add other data connections</a>&nbsp;
-          or trigger collection at the <a href='#' style={{ textDecoration: 'underline' }} onClick={cancel}>previous page</a>.
         </p>
       </div>
     </>
