@@ -236,7 +236,7 @@ const Pipelines = (props) => {
                       <a href='#' rel='noreferrer'><HelpIcon width={19} height={19} style={{ marginLeft: '10px' }} /></a>
                       <>
                         <div style={{ textShadow: 'none', fontSize: '12px', padding: '12px', maxWidth: '300px' }}>
-                          <div style={{ marginBottom: '10px', fontWeight: 700, fontSize: '14px', fontFamily: '"Montserrat", sans-serif' }}>
+                          <div style={{ marginBottom: '10px', fontWeight: 700, fontSize: '14px' }}>
                             <Icon icon='help' size={16} /> Manage Pipeline Runs
                           </div>
                           <p>Need Help? &mdash; Manage, Stop running and Restart failed pipelines.
@@ -563,7 +563,6 @@ const Pipelines = (props) => {
                                 letterSpacing: '2px',
                                 textTransform: 'uppercase',
                                 margin: 0,
-                                fontFamily: '"Montserrat", sans-serif'
                               }}
                               >0 Pipeline Runs
                               </h3>
