@@ -17,7 +17,10 @@ limitations under the License.
 
 package code
 
+import "github.com/apache/incubator-devlake/models/common"
+
 type CommitParent struct {
+	common.NoPKModel
 	CommitSha       string `json:"commitSha" gorm:"primaryKey;type:varchar(40);comment:commit hash"`
 	ParentCommitSha string `json:"parentCommitSha" gorm:"primaryKey;type:varchar(40);comment:parent commit hash"`
 }
