@@ -24,3 +24,7 @@ type PullRequestCommit struct {
 	PullRequestId string `json:"id" gorm:"primaryKey;type:varchar(255);comment:This key is generated based on details from the original plugin"` // format: <Plugin>:<Entity>:<PK0>:<PK1>
 	common.NoPKModel
 }
+
+func (PullRequestCommit) TableName() string {
+	return "pull_request_commits"
+}
