@@ -29,3 +29,7 @@ type RefsPrCherrypick struct {
 	ParentPrId             string `json:"parent_pr_id" gorm:"primaryKey;type:varchar(255);comment:This key is generated based on details from the original plugin"` // format: <Plugin>:<Entity>:<PK0>:<PK1>
 	common.NoPKModel
 }
+
+func (RefsPrCherrypick) TableName() string {
+	return "refs_pr_cherrypicks"
+}
