@@ -24,3 +24,7 @@ type IssueCommit struct {
 	IssueId   string `gorm:"primaryKey;type:varchar(255)"`
 	CommitSha string `gorm:"primaryKey;type:varchar(255)"`
 }
+
+func (IssueCommit) TableName() string {
+	return "issue_commits"
+}
