@@ -23,5 +23,10 @@ import (
 
 type Job struct {
 	Name string `gorm:"type:varchar(255)"`
+	Type string `gorm:"type:varchar(255)"`
 	domainlayer.DomainEntity
 }
+
+func (Job) TableName() string {
+	return "jobs"
+}
