@@ -21,3 +21,7 @@ type Job struct {
 	Name string `gorm:"type:varchar(255)"`
 	DomainEntity
 }
+
+func (Job) TableName() string {
+	return "jobs"
+}
