@@ -31,5 +31,10 @@ func All() []migration.Script {
 		new(addTypeField),
 		new(commitfileComponent),
 		new(removeNotes),
+		new(addProjectMapping),
+		new(renameColumnsOfPullRequestIssue),
+		new(addNoPKModelToCommitParent),
+		new(addSubtasksTable),
+		new(addCICD),
 	}
 }
