@@ -46,12 +46,6 @@ func CreateApiClient(taskCtx core.TaskContext, connection *models.GithubConnecti
 		tokenIndex = (tokenIndex + 1) % len(tokens)
 		return nil
 	})
-	apiClient.SetAfterFunction(func(res *http.Response) error {
-		if res.StatusCode == http.StatusUnauthorized {
-			return fmt.Errorf("authentication failed, please check your AccessToken configuration")
-		}
-		return nil
-	})
 
 	// create rate limit calculator
 	rateLimiter := &helper.ApiRateLimitCalculator{
