@@ -23,18 +23,21 @@ import (
 	"github.com/spf13/cobra"
 )
 
-// Export a variable named PluginEntry for Framework to search and load
+// PluginEntry is a variable exported for Framework to search and load
 var PluginEntry impl.Gitlab //nolint
 
 // standalone mode for debugging
 func main() {
 	gitlabCmd := &cobra.Command{Use: "gitlab"}
 	projectId := gitlabCmd.Flags().IntP("project-id", "p", 0, "gitlab project id")
+	connectionId := gitlabCmd.Flags().Uint64P("connection-id", "c", 0, "gitlab connection id")
 
 	_ = gitlabCmd.MarkFlagRequired("project-id")
+	_ = gitlabCmd.MarkFlagRequired("connection-id")
 	gitlabCmd.Run = func(cmd *cobra.Command, args []string) {
 		runner.DirectRun(cmd, args, PluginEntry, map[string]interface{}{
-			"projectId": *projectId,
+			"projectId":    *projectId,
+			"connectionId": *connectionId,
 		})
 	}
 
