@@ -77,7 +77,13 @@ func ConvertMergeRequestComment(taskCtx core.SubTaskContext) error {
 				Body:          gitlabComments.Body,
 				UserId:        accountIdGen.Generate(data.Options.ConnectionId, gitlabComments.AuthorUserId),
 				CreatedDate:   gitlabComments.GitlabCreatedAt,
-				Type:          gitlabComments.Type,
+			}
+			domainComment.Type = getStdCommentType(gitlabComments.Type)
+			if domainComment.Body == "unapproved this merge request" {
+				domainComment.Status = "CHANGES_REQUESTED"
+			}
+			if domainComment.Body == "approved this merge request" {
+				domainComment.Status = "APPROVED"
 			}
 			return []interface{}{
 				domainComment,
@@ -90,3 +96,13 @@ func ConvertMergeRequestComment(taskCtx core.SubTaskContext) error {
 
 	return converter.Execute()
 }
+
+func getStdCommentType(originType string) string {
+	if originType == "DiffNote" {
+		return code.DIFF_COMMENT
+	}
+	if originType == "REVIEW" {
+		return code.REVIEW
+	}
+	return code.NORMAL_COMMENT
+}
