@@ -17,8 +17,14 @@ limitations under the License.
 
 package helper
 
+// ListBaseNode 'abstract' base struct for Nodes that are chained in a linked list manner
 type ListBaseNode struct {
-	next interface{}
+	next QueueNode
+}
+
+func (l *ListBaseNode) Data() interface{} {
+	// default implementation
+	return nil
 }
 
 func (l *ListBaseNode) Next() interface{} {
@@ -29,10 +35,14 @@ func (l *ListBaseNode) Next() interface{} {
 }
 
 func (l *ListBaseNode) SetNext(next interface{}) {
-	l.next = next
+	if next == nil {
+		l.next = nil
+	} else {
+		l.next = next.(QueueNode)
+	}
 }
 
-// NewListBaseNode create and init a new node
+// NewListBaseNode create and init a new node (only to be called by subclasses)
 func NewListBaseNode() *ListBaseNode {
 	return &ListBaseNode{
 		next: nil,
