@@ -18,23 +18,48 @@ limitations under the License.
 package tasks
 
 import (
+	"fmt"
 	"time"
 
 	"github.com/apache/incubator-devlake/plugins/helper"
 	"github.com/apache/incubator-devlake/plugins/jira/models"
+	"github.com/mitchellh/mapstructure"
 )
 
+type TransformationRules struct {
+	EpicKeyField               string `json:"epicKeyField"`
+	StoryPointField            string `json:"storyPointField"`
+	RemotelinkCommitShaPattern string `json:"remotelinkCommitShaPattern"`
+	TypeMappings               map[string]struct {
+		StandardType string `json:"standardType"`
+	} `json:"typeMappings"`
+}
+
 type JiraOptions struct {
-	ConnectionId uint64   `json:"connectionId"`
-	BoardId      uint64   `json:"boardId"`
-	Tasks        []string `json:"tasks,omitempty"`
-	Since        string
+	ConnectionId        uint64 `json:"connectionId"`
+	BoardId             uint64 `json:"boardId"`
+	Since               string
+	TransformationRules TransformationRules `json:"transformationRules"`
 }
 
 type JiraTaskData struct {
 	Options        *JiraOptions
 	ApiClient      *helper.ApiAsyncClient
-	Connection     *models.JiraConnection
 	Since          *time.Time
 	JiraServerInfo models.JiraServerInfo
 }
+
+func DecodeAndValidateTaskOptions(options map[string]interface{}) (*JiraOptions, error) {
+	var op JiraOptions
+	err := mapstructure.Decode(options, &op)
+	if err != nil {
+		return nil, err
+	}
+	if op.ConnectionId == 0 {
+		return nil, fmt.Errorf("invalid connectionId:%d", op.ConnectionId)
+	}
+	if op.BoardId == 0 {
+		return nil, fmt.Errorf("invalid boardId:%d", op.BoardId)
+	}
+	return &op, nil
+}
