@@ -17,17 +17,15 @@ limitations under the License.
 
 package archived
 
-import (
-	"github.com/apache/incubator-devlake/models/common"
-)
+import "github.com/apache/incubator-devlake/models/migrationscripts/archived"
 
 type TapdBugStatus struct {
 	ConnectionId uint64 `gorm:"primaryKey"`
-	WorkspaceID  uint64 `gorm:"primaryKey"`
+	WorkspaceId  uint64 `gorm:"primaryKey"`
 	EnglishName  string `gorm:"primaryKey;type:varchar(255)"`
 	ChineseName  string
 	IsLastStep   bool
-	common.NoPKModel
+	archived.NoPKModel
 }
 
 func (TapdBugStatus) TableName() string {
