@@ -18,18 +18,18 @@ limitations under the License.
 package archived
 
 import (
-	"github.com/apache/incubator-devlake/models/common"
+	"github.com/apache/incubator-devlake/models/migrationscripts/archived"
 	"github.com/apache/incubator-devlake/plugins/helper"
 )
 
 type TapdIterationBug struct {
-	common.NoPKModel
+	archived.NoPKModel
 	ConnectionId   uint64 `gorm:"primaryKey"`
 	IterationId    uint64 `gorm:"primaryKey"`
-	WorkspaceID    uint64 `gorm:"primaryKey"`
+	WorkspaceId    uint64 `gorm:"primaryKey"`
 	BugId          uint64 `gorm:"primaryKey"`
-	ResolutionDate helper.CSTTime
-	BugCreatedDate helper.CSTTime
+	ResolutionDate *helper.CSTTime
+	BugCreatedDate *helper.CSTTime
 }
 
 func (TapdIterationBug) TableName() string {
