@@ -26,10 +26,10 @@ type TapdIterationStory struct {
 	common.NoPKModel
 	ConnectionId     uint64 `gorm:"primaryKey"`
 	IterationId      uint64 `gorm:"primaryKey"`
-	WorkspaceID      uint64 `gorm:"primaryKey"`
+	WorkspaceId      uint64 `gorm:"primaryKey"`
 	StoryId          uint64 `gorm:"primaryKey"`
-	ResolutionDate   helper.CSTTime
-	StoryCreatedDate helper.CSTTime
+	ResolutionDate   *helper.CSTTime
+	StoryCreatedDate *helper.CSTTime
 }
 
 func (TapdIterationStory) TableName() string {
