@@ -21,6 +21,7 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
+	"github.com/apache/incubator-devlake/logger"
 	"time"
 
 	"github.com/apache/incubator-devlake/config"
@@ -38,8 +39,8 @@ import (
 // RunTask FIXME ...
 func RunTask(
 	ctx context.Context,
-	cfg *viper.Viper,
-	logger core.Logger,
+	_ *viper.Viper,
+	parentLogger core.Logger,
 	db *gorm.DB,
 	progress chan core.RunningProgress,
 	taskId uint64,
@@ -52,6 +53,10 @@ func RunTask(
 	if task.Status == models.TASK_COMPLETED {
 		return fmt.Errorf("invalid task status")
 	}
+	log, err := getTaskLogger(parentLogger, task)
+	if err != nil {
+		return err
+	}
 	beganAt := time.Now()
 	// make sure task status always correct even if it panicked
 	defer func() {
@@ -73,7 +78,7 @@ func RunTask(
 				"failed_sub_task": subTaskName,
 			}).Error
 			if dbe != nil {
-				logger.Error("failed to finalize task status into db: %w", err)
+				log.Error("failed to finalize task status into db: %w", err)
 			}
 		} else {
 			err = db.Model(task).Updates(map[string]interface{}{
@@ -86,7 +91,7 @@ func RunTask(
 	}()
 
 	// start execution
-	logger.Info("start executing task: %d", task.ID)
+	log.Info("start executing task: %d", task.ID)
 	err = db.Model(task).Updates(map[string]interface{}{
 		"status":   models.TASK_RUNNING,
 		"message":  "",
@@ -110,8 +115,9 @@ func RunTask(
 	err = RunPluginTask(
 		ctx,
 		config.GetConfig(),
-		logger.Nested(task.Plugin),
+		log.Nested(task.Plugin),
 		db,
+		task.ID,
 		task.Plugin,
 		subtasks,
 		options,
@@ -126,6 +132,7 @@ func RunPluginTask(
 	cfg *viper.Viper,
 	logger core.Logger,
 	db *gorm.DB,
+	taskID uint64,
 	name string,
 	subtasks []string,
 	options map[string]interface{},
@@ -139,12 +146,12 @@ func RunPluginTask(
 	if !ok {
 		return fmt.Errorf("plugin %s doesn't support PluginTask interface", name)
 	}
-
 	return RunPluginSubTasks(
 		ctx,
 		cfg,
 		logger,
 		db,
+		taskID,
 		name,
 		subtasks,
 		options,
@@ -159,8 +166,9 @@ func RunPluginSubTasks(
 	cfg *viper.Viper,
 	logger core.Logger,
 	db *gorm.DB,
+	taskID uint64,
 	name string,
-	subtasks []string,
+	subtaskNames []string,
 	options map[string]interface{},
 	pluginTask core.PluginTask,
 	progress chan core.RunningProgress,
@@ -181,10 +189,10 @@ func RunPluginSubTasks(
 	*/
 
 	// user specifies what subtasks to run
-	if len(subtasks) != 0 {
+	if len(subtaskNames) != 0 {
 		// decode user specified subtasks
 		var specifiedTasks []string
-		err := mapstructure.Decode(subtasks, &specifiedTasks)
+		err := mapstructure.Decode(subtaskNames, &specifiedTasks)
 		if err != nil {
 			return err
 		}
@@ -231,7 +239,7 @@ func RunPluginSubTasks(
 
 	// execute subtasks in order
 	taskCtx.SetProgress(0, steps)
-	i := 0
+	subtaskNumber := 0
 	for _, subtaskMeta := range subtaskMetas {
 		subtaskCtx, err := taskCtx.SubTaskContext(subtaskMeta.Name)
 		if err != nil {
@@ -245,15 +253,15 @@ func RunPluginSubTasks(
 
 		// run subtask
 		logger.Info("executing subtask %s", subtaskMeta.Name)
-		i++
+		subtaskNumber++
 		if progress != nil {
 			progress <- core.RunningProgress{
 				Type:          core.SetCurrentSubTask,
 				SubTaskName:   subtaskMeta.Name,
-				SubTaskNumber: i,
+				SubTaskNumber: subtaskNumber,
 			}
 		}
-		err = subtaskMeta.EntryPoint(subtaskCtx)
+		err = runSubtask(logger, db, taskID, subtaskNumber, subtaskCtx, subtaskMeta.EntryPoint)
 		if err != nil {
 			return &errors.SubTaskError{
 				SubTaskName: subtaskMeta.Name,
@@ -292,3 +300,47 @@ func UpdateProgressDetail(db *gorm.DB, logger core.Logger, taskId uint64, progre
 		progressDetail.SubTaskNumber = p.SubTaskNumber
 	}
 }
+
+func runSubtask(
+	logger core.Logger,
+	db *gorm.DB,
+	parentID uint64,
+	subtaskNumber int,
+	ctx core.SubTaskContext,
+	entryPoint core.SubTaskEntryPoint,
+) error {
+	beginAt := time.Now()
+	subtask := &models.Subtask{
+		Name:    ctx.GetName(),
+		TaskID:  parentID,
+		Number:  subtaskNumber,
+		BeganAt: &beginAt,
+	}
+	defer func() {
+		finishedAt := time.Now()
+		subtask.FinishedAt = &finishedAt
+		subtask.SpentSeconds = finishedAt.Unix() - beginAt.Unix()
+		recordSubtask(logger, db, subtask)
+	}()
+	return entryPoint(ctx)
+}
+
+func recordSubtask(logger core.Logger, db *gorm.DB, subtask *models.Subtask) {
+	if err := db.Create(&subtask).Error; err != nil {
+		logger.Error("error writing subtask %d status to DB: %v", subtask.ID, err)
+	}
+}
+
+func getTaskLogger(parentLogger core.Logger, task *models.Task) (core.Logger, error) {
+	log := parentLogger.Nested(fmt.Sprintf("task #%d", task.ID))
+	loggingPath := logger.GetTaskLoggerPath(log.GetConfig(), task)
+	stream, err := logger.GetFileStream(loggingPath)
+	if err != nil {
+		return nil, err
+	}
+	log.SetStream(&core.LoggerStreamConfig{
+		Path:   loggingPath,
+		Writer: stream,
+	})
+	return log, nil
+}
