@@ -23,12 +23,13 @@ import (
 	"strings"
 )
 
-func GatherCallFrames() string {
+// GatherCallFrames FIXME ...
+func GatherCallFrames(delta int) string {
 	var name, file string
 	var line int
 	var pc [16]uintptr
 
-	n := runtime.Callers(3, pc[:])
+	n := runtime.Callers(3+delta, pc[:])
 	for _, pc := range pc[:n] {
 		fn := runtime.FuncForPC(pc)
 		if fn == nil {
