@@ -27,8 +27,8 @@ import (
 )
 
 // DevLakeTaskActivity FIXME ...
-func DevLakeTaskActivity(ctx context.Context, configJson []byte, taskId uint64) error {
-	cfg, log, db, err := loadResources(configJson)
+func DevLakeTaskActivity(ctx context.Context, configJson []byte, taskId uint64, loggerConfig *core.LoggerConfig) error {
+	cfg, log, db, err := loadResources(configJson, loggerConfig)
 	if err != nil {
 		return err
 	}
